Overview
========

lvlspy is a python package for working with quantum level-system data.

|pypi| |doc_stat| |license| |pytest| |pylint| |black|

Installation
------------

Install from `PyPI <https://pypi.org/project/lvlspy>`_ with pip by
typing in your favorite terminal::

    $ pip install lvlspy 

If you already have installed and wish to update lvlspy to the latest version, you will have to do it via::

    $ pip install lvlspy --upgrade
    
We are working on bringing lvlspy to Anaconda. For now, you will have to use the built-in pip manager in Anaconda instead of the conda package manager. This page will be updated when the package is up on Anaconda. 
	
Usage
-----

To get familiar with lvlspy, please see our tutorial `Jupyter
notebooks <https://github.com/jaadt7/lvlspy_tutorial>`_.

Documentation
-------------

The project documentation is available at `<https://lvlspy.readthedocs.io>`_.

Attribution
-----------
To cite this code, please visit the `Zenodo <https://zenodo.org/badge/latestdoi/532987706>`_ page
for this project.  From that page, you can export the appropriate reference in BibTex or other formats.

Authors
-------

- Jaad A. Tannous <jtannou@g.clemson.edu>
- Bradley S. Meyer <mbradle@g.clemson.edu>

Contribute
----------

- Issue Tracker: `<https://github.com/jaadt7/issues/>`_
- Source Code: `<https://github.com/jaadt7/lvlspy/>`_

License
-------

The project is licensed under the GNU Public License v3 (or later).

.. |pypi| image:: https://badge.fury.io/py/lvlspy.svg
    :target: https://badge.fury.io/py/lvlspy 
.. |license| image:: https://img.shields.io/github/license/jaadt7/lvlspy
    :alt: GitHub
.. |doc_stat| image:: https://readthedocs.org/projects/lvlspy/badge/?version=latest
    :target: https://lvlspy.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status
.. |pytest| image:: https://github.com/jaadt7/lvlspy/actions/workflows/test.yml/badge.svg?branch=main&event=push
	:target: https://github.com/jaadt7/lvlspy/actions/workflows/test.yml
.. |pylint| image:: https://github.com/jaadt7/lvlspy/actions/workflows/lint.yml/badge.svg?branch=main&event=push
	:target: https://github.com/jaadt7/lvlspy/actions/workflows/lint.yml 
.. |black| image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github.com/psf/black
